# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitParentDetailsResponse(Model):
    """BillSplitParentDetailsResponse.

    :param split_parent_account: The split source account
    :type split_parent_account: ~energycap.sdk.models.AccountChild
    :param split_parent_meter: The split source meter
    :type split_parent_meter: ~energycap.sdk.models.MeterChild
    :param begin_date: First date that the bill split was active for
    :type begin_date: datetime
    :param end_date: Last date that the bill split was active for
     Date of 3000-01-01 indicates that the version is still active
    :type end_date: datetime
    """

    _attribute_map = {
        'split_parent_account': {'key': 'splitParentAccount', 'type': 'AccountChild'},
        'split_parent_meter': {'key': 'splitParentMeter', 'type': 'MeterChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, split_parent_account=None, split_parent_meter=None, begin_date=None, end_date=None):
        super(BillSplitParentDetailsResponse, self).__init__()
        self.split_parent_account = split_parent_account
        self.split_parent_meter = split_parent_meter
        self.begin_date = begin_date
        self.end_date = end_date
